{% load i18n static simpletags sptags %}
<link rel="stylesheet" href="{% static 'admin/simplepro/css/home.css' %}">
<div class="home-body">

    <el-row>
        <el-col :span="18">
            {% block quick %}
                <el-card>
                    <div slot="header">
                        {% trans 'Quick Action' %}
                    </div>
                    {% include 'admin/parts/quick.html' %}
                </el-card>
            {% endblock %}

            <el-card style="margin-top: 10px;">
                <div slot="header">
                    {% trans 'System Monitor' %}
                </div>
                <monitor ref="monitor" url="{% url 'sp:monitor' %}"></monitor>
            </el-card>
        </el-col>

        <el-col :span="6">

            {% block timeline %}
                   {% include 'admin/timeline.html' %}
            {% endblock %}
        </el-col>
    </el-row>
    <div style="height: 80px"></div>
</div>
<el-backtop target=".home-body"></el-backtop>
