<style type="text/css">
    #v_id_{{ name }} span[role="button"]{
        margin-top: 1px;
    }
</style>
<div id="v_id_{{ name }}">
        <input type="hidden" name="{{ name }}" value="{{ value }}" v-model="{{ name }}">
    <el-input-number v-model="{{ name }}"
                     size="small"
                     {% if min_value %}
                     :min="{{ min_value }}"
                     {% endif %}
                     {% if max_value %}
                     :max="{{ max_value }}"
                    {% endif %}
    >

    </el-input-number>
</div>
<script type="text/javascript">
    var {{ name }}_value='{{ value }}';
    var app_{{ name }} = new Vue({el:'#v_id_{{ name }}',
        data:{
            '{{ name }}':{{ name }}_value.split(','),
        }
    });
</script>