body {
  font-family: Helvetica Neue, Helvetica, PingFang SC, Hiragino Sans GB, Microsoft YaHei, SimSun, sans-serif;
  font-weight: 400;
  -webkit-font-smoothing: antialiased;
  -webkit-tap-highlight-color: transparent;
}
.active {
  text-align: center;
  max-width: 500px;
  margin-left: auto;
  margin-right: auto;
  margin-top: 50px;
}
.active .error-icon {
  display: inline-block;
  width: 72px;
  height: 72px;
  border-radius: 50px;
  background-color: #ed4013;
}
.active .error-icon i {
  color: white;
  font-size: 50px;
  text-align: center;
  margin-top: 10px;
}
.active .el-alert {
  margin-top: 50px;
}
.active .el-alert__content {
  margin: 20px auto;
}
.active .description {
  text-align: left;
}
.active .pay-type {
  text-align: left;
}
.active .card-box .active {
  border-color: #4C9AF2 !important;
}
.active .card-box .card {
  float: left;
  display: table;
  margin-right: 10px;
  margin-top: 10px;
  border: 1px #D6D6D6 solid;
  border-radius: 4px;
  width: 197px;
  background-color: #fff;
  position: relative;
  cursor: pointer;
}
.active .card-box .card .name,
.active .card-box .card .amount,
.active .card-box .card .day {
  display: table-cell;
}
.active .card-box .card .name {
  width: 56px;
  height: 60px;
  line-height: 60px;
  color: #707070;
  text-align: center;
  border-radius: 5px 0 0 5px;
  background: #ededed;
  font-size: 16px;
}
.active .card-box .card .amount {
  font-size: 24px;
  color: #F5622E;
  line-height: initial;
  text-align: left;
  padding-left: 5px;
  width: 78px;
}
.active .card-box:after {
  display: block;
  content: "";
  float: none;
  clear: both;
}
.active .pay-tips {
  font-size: 12px;
  margin: 10px;
  color: #666;
}
/*# sourceMappingURL=active.css.map */