<style type="text/css">
    #v_id_{{ name }}{
        display: inline-block;
        width: 250px;
    }
</style>
<div id="v_id_{{ name }}">
    <input type="hidden" name="{{ name }}" v-model="{{ name }}">
    <el-input v-model="{{ name }}" {% if style %} style="{{ style|safe }}"{% endif %} {{ attrs|safe }}>
        {% if slot %}
        <template slot="{{ slot }}">{{ slot_text }}</template>
        {% endif %}
    </el-input>
</div>
<script type="text/javascript">
    var app_{{ name }} = new Vue({el:'#v_id_{{ name }}',
        data:{
            '{{ name }}':'{{ value }}'
        }
    });
</script>