{% load i18n static %}
<form action="">
    {% csrf_token %}
    <table>
        {{ form }}
    </table>
</form>

引入自定义的css和js

{{ form.media }}
{% if media %}
    {% for js in media.js %}
        <script type="text/javascript" src="{% static js %}"></script>
    {% endfor %}

    {% for css in media.css %}
        {{ css }}
    {% endfor %}
{% endif %}