.helptext {
  font-size: 12px;
  color: #999;
}

input[type='text'], input[type='number'], input[type='password'] {
  -webkit-appearance: none;
  background-color: #fff;
  background-image: none;
  border-radius: 4px;
  border: 1px solid #dcdfe6;
  box-sizing: border-box;
  color: #606266;
  display: inline-block;
  font-size: inherit;
  height: 40px;
  line-height: 40px;
  outline: none;
  padding: 0 15px;
  transition: border-color .2s cubic-bezier(.645, .045, .355, 1);
  width: auto;

  &:focus {
    outline: none;
    border-color: #409eff;
  }
}

th {
  text-align: right;
  font-weight: normal;

  label {
    vertical-align: middle;
    //float: left;
    font-size: 14px;
    color: #606266;
    line-height: 40px;
    padding: 0 12px 0 0;
    box-sizing: border-box;
  }

  padding: 10px auto;
}

.errorlist {
  font-size: 12px;
  color: red;
}