body,
.bg {
  background-color: #f7f7f7 !important;
}
.banner img {
  width: 300px;
}
.header {
  font-size: 14px;
  color: #808695;
  font-weight: 300;
}
.design,
.design a {
  color: #808695;
  font-size: 14px;
  text-align: center;
}
.simpleui-input-inline {
  margin: 25px auto;
}
/*# sourceMappingURL=login.css.map */