<div id="v_id_{{ name }}">
    <input type="hidden" name="{{ name }}" v-model="{{ name }}">
    <el-switch v-model="{{ name }}"></el-switch>
</div>
<script type="text/javascript">
    var app_{{ name }} = new Vue({el:'#v_id_{{ name }}',
        data:{
            '{{ name }}':'{{ value }}'=='True'
        }
    });
</script>