
{% load static %}
<script type="text/javascript">
   var UEDITOR_CONFIG={{config|safe}};
       UEDITOR_CONFIG['serverUrl']='{% url 'sp:editor_upload' %}';
</script>
<div class="django-ueditor-widget" style="display: inline-block;">
    <textarea name="{{ name }}" id="ueditor">{{ value }}</textarea>
</div>
