.helptext {
  font-size: 12px;
  color: #999;
}
input[type='text'],
input[type='number'],
input[type='password'] {
  -webkit-appearance: none;
  background-color: #fff;
  background-image: none;
  border-radius: 4px;
  border: 1px solid #dcdfe6;
  box-sizing: border-box;
  color: #606266;
  display: inline-block;
  font-size: inherit;
  height: 40px;
  line-height: 40px;
  outline: none;
  padding: 0 15px;
  transition: border-color 0.2s cubic-bezier(0.645, 0.045, 0.355, 1);
  width: auto;
}
input[type='text']:focus,
input[type='number']:focus,
input[type='password']:focus {
  outline: none;
  border-color: #409eff;
}
th {
  text-align: right;
  font-weight: normal;
  padding: 10px auto;
}
th label {
  vertical-align: middle;
  font-size: 14px;
  color: #606266;
  line-height: 40px;
  padding: 0 12px 0 0;
  box-sizing: border-box;
}
.errorlist {
  font-size: 12px;
  color: red;
}
