{% extends "admin/base.html" %}
{% load static simpletags sptags %}
{% block extrahead %}
    {{ block.super }}
    <script type="text/javascript">
        if (parent.progress) {
            parent.progress.start();
        }
    </script>
    <style type="text/css">
        body {
            background: #f1f4f6;
        }

        #container {
            background: initial;
        }
    </style>
{% endblock %}

{% block footer %}
    {{ block.super }}
    <script type="text/javascript" src="{% static 'admin/simplepro/js/gotop.js' %}"></script>
    <template id="gotop">
        <gotop></gotop>
    </template>
    <script type="text/javascript">
        window.addEventListener('load', __ => {
            new Vue({el: '#gotop'});
            if (parent.progress) {
                parent.progress.done();
            }
        });
    </script>
{% endblock %}