{% load sptags %}
<div id="v_id_{{ name }}">
    <input type="hidden" name="{{ name }}" v-model="{{ name }}">

   <el-date-picker
    v-model="{{ name }}"
    {{ attrs |safe }}
    value-format="yyyy-MM-dd"
    format="yyyy-MM-dd"
    :picker-options="options"
    placeholder="{{ verbose_name }}">
   </el-date-picker>


</div>
<script type="text/javascript">
    var app_{{ name }} = new Vue({
        el: '#v_id_{{ name }}',
        data: {
            '{{ name }}': '{{ value|date:'Y-m-d' }}',
            options:{{ picker_options|safe }}
        }
    });
</script>