{% load i18n %}
{% load admin_urls %}

{% if has_export_permission %}
<li><a href="{% url opts|admin_urlname:'export' %}{{cl.get_query_string}}" class="export_link">{% trans "Export" %}</a></li>
{% endif %}
