import lzma,base64
exec(lzma.decompress(base64.b64decode(b'/Td6WFoAAATm1rRGAgAhARYAAAB0L+Wj4AFhAOVdADMciiJvqlzh/FMS3SwZ+nQSa6H36gsLbA+rHUCOsyIRHODDQwXl44OqCJdEynRCq3+HnPJ7fECiJm94X12/oxuSXGbhU7b0b/xRA9tXLSjkVFyFwvd67yhT86ngSkSz1vTH+llTfasA7jEzbJi/bXSWlFj0mutLCOGnkYepZgBIgkkX54GHax5x+gPVGooIOWpSq55NbhmUdrob09bwSYF43kC3BW60BXk76Is3jr9ZaNMyHx6FlvXxEINvcHNm+mUjDYFRw97xaAwo6gvwWtqIqb5AgsJE6zseBTrUGH6n8xbPIAAAAAAA034A4R40AtYAAYEC4gIAAB0dixOxxGf7AgAAAAAEWVo=')))