.el-tabs--border-card > .el-tabs__header .el-tabs__item.is-active {
  color: #515a6e !important;
  border-bottom: #515a6e 2px solid !important;
}
.el-button--text {
  color: #515a6e !important;
}
.el-button--primary:focus,
.el-button--primary:hover {
  color: #515a6e;
  border-color: rgba(81, 90, 110, 0.9) !important;
  background-color: rgba(81, 90, 110, 0.8) !important;
}
.el-dropdown-menu__item:focus,
.el-dropdown-menu__item:not(.is-disabled):hover {
  background-color: rgba(81, 90, 110, 0.2) !important;
  color: #515a6e !important;
}
.el-select-dropdown__item.selected {
  color: #515a6e !important;
}
input[type=text]:focus,
input[type=password]:focus,
input[type=email]:focus,
input[type=url]:focus,
input[type=number]:focus,
input[type=tel]:focus,
textarea:focus,
select:focus,
.vTextField:focus {
  border-color: #515a6e !important;
}
.el-button--primary {
  background-color: #515a6e !important;
  border-color: #515a6e !important;
}
tbody a:link,
tbody a:visited {
  color: #515a6e !important;
}
tbody tr:hover td,
tbody tr:hover th {
  background-color: rgba(81, 90, 110, 0.2) !important;
}
a:link,
a:visited {
  color: #515a6e !important;
}
.results {
  color: inherit !important;
}
.el-select-dropdown__item.hover,
.el-select-dropdown__item:hover {
  background-color: rgba(81, 90, 110, 0.2) !important;
}
.el-date-table td.today span {
  color: #515a6e !important;
}
.el-date-table td.available:hover {
  color: #515a6e !important;
}
.el-picker-panel__icon-btn:hover {
  color: rgba(81, 90, 110, 0.8) !important;
}
.el-range-editor.is-active,
.el-range-editor.is-active:hover {
  border-color: #515a6e !important;
}
.el-date-table td.end-date span,
.el-date-table td.start-date span {
  background-color: #515a6e !important;
}
.el-date-table td.in-range div,
.el-date-table td.in-range div:hover,
.el-date-table.is-week-mode .el-date-table__row.current div,
.el-date-table.is-week-mode .el-date-table__row:hover div {
  background-color: rgba(81, 90, 110, 0.2) !important;
}
.el-time-panel__btn.confirm {
  color: #515a6e !important;
}
.el-pagination.is-background .el-pager li:not(.disabled).active {
  color: #515a6e;
  background-color: #515a6e !important;
}
.el-pagination.is-background .el-pager li:not(.disabled):hover {
  color: #515a6e !important;
}
.el-tabs--border-card > .el-tabs__header .el-tabs__item:not(.is-disabled):hover {
  color: #515a6e !important;
}
.navbar {
  background-color: #304457;
}
.navbar .el-button:focus,
.navbar .el-button:hover {
  color: #515a6e !important;
}
.navbar .el-button,
.navbar .el-breadcrumb__item:last-child .el-breadcrumb__inner,
.navbar .el-breadcrumb__item:last-child .el-breadcrumb__inner a,
.navbar .el-breadcrumb__item:last-child .el-breadcrumb__inner a:hover,
.navbar .el-breadcrumb__item:last-child .el-breadcrumb__inner:hover {
  color: #fff;
}
.navbar .el-breadcrumb__inner,
.navbar .el-breadcrumb__separator {
  color: #fff;
}
.logo-wrap {
  color: hsla(0, 0%, 100%, 0.7) !important;
}
.menu {
  background-color: #191a23 !important;
}
.menu .el-menu-item {
  color: hsla(0, 0%, 100%, 0.7) !important;
}
.menu .el-menu-item:hover {
  color: #FFF;
}
.menu .el-menu .is-active {
  color: #515a6e !important;
}
.menu .el-menu-item-group,
.menu .el-menu-item {
  background-color: #191a23 !important;
}
.menu .el-menu-item:hover {
  background-color: #000000 !important;
  color: #FFF !important;
}
.menu .el-menu-item i {
  color: inherit;
}
.menu .el-submenu__title .far,
.menu .el-submenu__title .fa,
.menu .el-submenu__title .fab,
.menu .el-submenu__title .fas {
  color: inherit;
}
.menu .el-submenu__title i {
  color: hsla(0, 0%, 100%, 0.7) !important;
}
.menu .el-submenu__title {
  color: hsla(0, 0%, 100%, 0.7) !important;
  background-color: #191a23 !important;
}
.menu .el-submenu__title:hover,
.menu .is-opened .el-submenu__title {
  color: #FFF !important;
  background-color: #000000 !important;
}
.quick-card a:hover {
  color: rgba(81, 90, 110, 0.8) !important;
}
.module h2,
.module caption,
.inline-group h2,
.selector-chosen h2 {
  background: #fff !important;
  color: #FFF !important;
}
#changelist .actions {
  min-height: 38px;
}
.colM {
  overflow: auto;
}
.toolbar .el-button {
  box-shadow: 0 3px 10px 0 rgba(0, 0, 0, 0.2);
}
.toolbar .el-button-group .el-button {
  box-shadow: none;
}
.logo-wrap {
  color: #c79c6d !important;
  background-color: #191a23 !important;
  padding-left: 20px;
  text-align: center;
}
.menu .el-menu .is-active {
  color: #c79c6d !important;
}
.menu *:not(span,i) {
  background-color: #191a23 !important;
}
.navbar .el-button:focus,
.navbar .el-button:hover {
  color: rgba(81, 90, 110, 0.7) !important;
}
.logo-wrap {
  font-size: 20px;
  font-weight: 300;
  color: white;
  height: 65px;
  line-height: 65px;
  border-bottom: 1px solid #101117;
  background: #191a23;
}
.menu .fa,
.menu .fas,
.menu .far,
.menu .fab {
  font-size: 14px;
}
.el-pagination.is-background .el-pager li:not(.disabled).active {
  color: #FFF;
}
.body,
.panel {
  background-color: #1d2935;
  color: #fff;
}
.el-form-item__label,
.el-breadcrumb__inner {
  color: #fff !important;
}
.el-input__inner,
.el-input__inner .el-range-input {
  background-color: #2f3e4e;
  border-color: rgba(47, 62, 78, 0.5);
  color: #fff;
}
.el-button--default {
  background-color: #2c3e50;
  color: #fff;
  border-color: #37495a;
}
.el-button--default:hover {
  background-color: #536d8a;
}
.el-tabs--border-card > .el-tabs__header {
  background-color: #304457;
  border: none;
  margin: 0;
}
.el-tabs--border-card {
  border: none;
}
#main .el-tabs__item {
  background-color: #304457;
}
.el-tabs--border-card > .el-tabs__header .el-tabs__item.is-active {
  color: #fff !important;
  border-right-color: #304457 !important;
  border-left-color: #304457 !important;
  border-bottom: #42b983 2px solid !important;
}
.el-select-dropdown {
  background-color: #3a5169;
  border: 0px;
}
.el-select-dropdown .el-select-dropdown__item {
  color: #fff;
}
.el-select-dropdown .el-select-dropdown__item:hover {
  background-color: #304457 !important;
}
.el-picker-panel {
  background-color: #304457;
  border: 0px;
}
.el-picker-panel .el-picker-panel__footer {
  background-color: #304457;
  border-color: #2c3e50;
}
.el-picker-panel .el-date-range-picker__content.is-left {
  border-color: #2c3e50;
}
.el-picker-panel .el-date-table th,
.el-picker-panel .el-date-range-picker__time-header {
  border-bottom-color: #2c3e50;
}
.el-popper[x-placement^=bottom] .popper__arrow::after {
  border-bottom-color: #304457 !important;
}
.el-table td,
.el-table th.is-leaf,
.el-table--border,
.el-table--group {
  border-color: #2c3e50;
}
.el-table th,
.el-table tr {
  background-color: #304457;
}
.el-table--striped .el-table__body tr.el-table__row--striped td {
  background: #1d2935;
}
/*# sourceMappingURL=dark.css.map */